# The COPYRIGHT file at the top level of
# this repository contains the full copyright notices and license terms.
from trytond.model import fields
from trytond.pool import PoolMeta

__all__ = ['Configuration', 'UnitLoad']


class Configuration:
    __metaclass__ = PoolMeta
    __name__ = 'stock.configuration'
    edocument_sequence = fields.Property(
        fields.Many2One('ir.sequence', 'Electronic Document Sequence',
                        required=True))
    EDI_output_path = fields.Property(fields.Char('EDI Output Path'))


class UnitLoad:
    __metaclass__ = PoolMeta
    __name__ = 'stock.unit_load'

    def get_best_before(self):
        return ''

    def get_sscc(self):
        if self.shipment_out:
            edi_codes = [identifier.code for identifier in
                         self.shipment_out.company.party.identifiers
                         if identifier.type == 'EDI_sender']
            edi_code = edi_codes[0][:6] if edi_codes else '000000'
            code = '00' + edi_code + self.code[-9:].zfill(len(self.code[-9:])-9)
            return code + str(self._sscc_control_digit(code))
        return ''

    def get_grai(self):
        return ''

    @staticmethod
    def _sscc_control_digit(num):
        nums = (int(c) for c in num)
        multipliers = [3, 1]
        return 10 - sum((digit * multipliers[index % 2]
            for index, digit in enumerate(nums))) % 10
